<?php

namespace Futage\Show\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Futage\Show\Interfaces\EpisodeRepositoryInterface;

class EpisodePublicController extends BaseController
{
    // use EpisodeWorkflow;

    /**
     * Constructor.
     *
     * @param type \Futage\Episode\Interfaces\EpisodeRepositoryInterface $episode
     *
     * @return type
     */
    public function __construct(EpisodeRepositoryInterface $episode)
    {
        $this->repository = $episode;
        parent::__construct();
    }

    /**
     * Show episode's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $episodes = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$show::$episode.names'))
            ->view('$show::public.episode.index')
            ->data(compact('$episodes'))
            ->output();
    }

    /**
     * Show episode's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $episodes = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$show::$episode.names'))
            ->view('$show::public.episode.index')
            ->data(compact('$episodes'))
            ->output();
    }

    /**
     * Show episode.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $episode = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$episode->name . trans('$show::$episode.name'))
            ->view('$show::public.episode.show')
            ->data(compact('$episode'))
            ->output();
    }

}
