<?php

namespace Futage\Show\Policies;

use Litepie\User\Contracts\UserPolicy;
use Futage\Show\Models\Episode;

class EpisodePolicy
{

    /**
     * Determine if the given user can view the episode.
     *
     * @param UserPolicy $user
     * @param Episode $episode
     *
     * @return bool
     */
    public function view(UserPolicy $user, Episode $episode)
    {
        if ($user->canDo('show.episode.view') && $user->isAdmin()) {
            return true;
        }

        return $episode->user_id == user_id() && $episode->user_type == user_type();
    }

    /**
     * Determine if the given user can create a episode.
     *
     * @param UserPolicy $user
     * @param Episode $episode
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('show.episode.create');
    }

    /**
     * Determine if the given user can update the given episode.
     *
     * @param UserPolicy $user
     * @param Episode $episode
     *
     * @return bool
     */
    public function update(UserPolicy $user, Episode $episode)
    {
        if ($user->canDo('show.episode.edit') && $user->isAdmin()) {
            return true;
        }

        return $episode->user_id == user_id() && $episode->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given episode.
     *
     * @param UserPolicy $user
     * @param Episode $episode
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Episode $episode)
    {
        return $episode->user_id == user_id() && $episode->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given episode.
     *
     * @param UserPolicy $user
     * @param Episode $episode
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Episode $episode)
    {
        if ($user->canDo('show.episode.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given episode.
     *
     * @param UserPolicy $user
     * @param Episode $episode
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Episode $episode)
    {
        if ($user->canDo('show.episode.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
