<?php

namespace Futage\Show\Policies;

use Litepie\User\Contracts\UserPolicy;
use Futage\Show\Models\Show;

class ShowPolicy
{

    /**
     * Determine if the given user can view the show.
     *
     * @param UserPolicy $user
     * @param Show $show
     *
     * @return bool
     */
    public function view(UserPolicy $user, Show $show)
    {
        if ($user->canDo('show.show.view') && $user->isAdmin()) {
            return true;
        }

        return $show->user_id == user_id() && $show->user_type == user_type();
    }

    /**
     * Determine if the given user can create a show.
     *
     * @param UserPolicy $user
     * @param Show $show
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('show.show.create');
    }

    /**
     * Determine if the given user can update the given show.
     *
     * @param UserPolicy $user
     * @param Show $show
     *
     * @return bool
     */
    public function update(UserPolicy $user, Show $show)
    {
        if ($user->canDo('show.show.edit') && $user->isAdmin()) {
            return true;
        }

        return $show->user_id == user_id() && $show->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given show.
     *
     * @param UserPolicy $user
     * @param Show $show
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Show $show)
    {
        return $show->user_id == user_id() && $show->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given show.
     *
     * @param UserPolicy $user
     * @param Show $show
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Show $show)
    {
        if ($user->canDo('show.show.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given show.
     *
     * @param UserPolicy $user
     * @param Show $show
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Show $show)
    {
        if ($user->canDo('show.show.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
